#ifndef TARGETLINE_H
#define TARGETLINE_H

#include "Line.h"
/**
 * TargetLine interface
 */
class TargetLine : public Line
{
public:
	TargetLine() { }
	~TargetLine() { }
	virtual DEV_ERR_CODE Open() = 0;
	virtual DEV_ERR_CODE Close() = 0;
	virtual DEV_ERR_CODE Start() = 0;
	virtual DEV_ERR_CODE Stop() = 0;
	virtual DEV_ERR_CODE Write(char bytes[], uint32 numBytes, bool8 isSigned, uint32 *numWritten) = 0;
	virtual DEV_ERR_CODE GetNumBytesWritable(uint32 *numWritable) = 0;
	virtual DEV_ERR_CODE GetNumBytesBuffer(uint32 *numBytes) = 0;
	virtual bool8 IsOpen() = 0;
	virtual bool8 IsStarted() = 0;
	virtual uint32 GetSampleRateHz() = 0;
	virtual uint32 GetNumChannels() = 0;
	virtual uint32 GetNumBytesPerSample() = 0;
	virtual void GetName(char name[], uint32 numChars, uint32 *numCharsRequired) = 0;
	
	/**
	 * Forward to num writable function
	 */
	DEV_ERR_CODE GetNumReadWrite(uint32 *numReadWrite)
	{
		return this->GetNumBytesWritable(numReadWrite);
	}

	/**
	 * Forward to write function
	 */
	DEV_ERR_CODE ReadWrite(char bytes[], uint32 numBytes, bool8 isSigned, uint32 *numReadWrite)
	{
		return this->Write(bytes, numBytes, isSigned, numReadWrite);
	}

	/**
	 * Return source line identifier
	 */
	LineType GetType()
	{
		return TARGET_LINE;
	}

};

#endif