/**
 * Author: Michael Feilen
 * Date created: 29.05.2009
 * Last changed: 05.06.2009 (mfeilen)
 * Description: THIS IS THE IMPLEMENATION OF THE JNI FOR SPARK.
 *				SPARK USES THIS INTERFACE TO TALK TO THE IMPLEMENTATION OF THE
 *              NATIVE PCM DEVICE
 *
 * --- DO NOT EDIT ---
 */
#include "de_ses_common_nativelibs_NativePCMDevice.h"
#include "NativePCMDevice.h"

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetType
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetType
  (JNIEnv *env, jclass, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetType(lineID, (LineType*)ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetNumBytesReadableWritable
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetNumBytesReadableWritable
  (JNIEnv *env, jclass c, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetNumBytesReadWrite(lineID, ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_ReadWrite
 * Signature: (I[BIZ[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1ReadWrite
  (JNIEnv *env, jclass, jint lineID, jbyteArray data, jint numBytes, jboolean isSigned, jintArray numWritten)
{
	char *ptrData = (char*)env->GetPrimitiveArrayCritical(data, JNI_FALSE);
	uint32 *ptrNumWritten = (uint32*)env->GetPrimitiveArrayCritical(numWritten, JNI_FALSE);
	jint errCode = (jint)Native_Line_ReadWrite(lineID, ptrData, numBytes, isSigned, ptrNumWritten);
	env->ReleasePrimitiveArrayCritical(data, ptrData, JNI_ABORT);
	env->ReleasePrimitiveArrayCritical(numWritten, ptrNumWritten, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetNumBytesBuffer
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetNumBytesBuffer
  (JNIEnv *env, jclass, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetNumBytesBuffer(lineID, ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_Open
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1Open
  (JNIEnv *env, jclass, jint lineUID)
{
	return (jint)Native_Line_Open(lineUID);
}


/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_IsOpen
 * Signature: (I[Z)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1IsOpen
  (JNIEnv *env, jclass, jint lineUID, jbooleanArray isOpen)
{
	bool8 *ptrIsOpen = (bool8*)env->GetPrimitiveArrayCritical(isOpen, JNI_FALSE);
	jint errCode = (jint)Native_Line_IsOpen(lineUID, ptrIsOpen);
	env->ReleasePrimitiveArrayCritical(isOpen, ptrIsOpen, JNI_ABORT);
	return errCode; 
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_IsStarted
 * Signature: (I[Z)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1IsStarted
  (JNIEnv *env, jclass, jint lineUID, jbooleanArray isStarted)
{
	bool8 *ptrIsStarted = (bool8*)env->GetPrimitiveArrayCritical(isStarted, JNI_FALSE);
	jint errCode = (jint)Native_Line_IsStarted(lineUID, ptrIsStarted);
	env->ReleasePrimitiveArrayCritical(isStarted, ptrIsStarted, JNI_ABORT);
	return errCode; 
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_Close
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1Close
  (JNIEnv *, jclass, jint lineID)
{
	return (jint)Native_Line_Close(lineID);
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_Start
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1Start
  (JNIEnv *, jclass, jint lineID)
{
	return (jint)Native_Line_Start(lineID);
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_Stop
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1Stop
  (JNIEnv *, jclass, jint lineID)
{
	return (jint)Native_Line_Stop(lineID);
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Dev_GetVersion
 * Signature: ([B[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Dev_1GetVersion
  (JNIEnv *env, jclass, jbyteArray strBuf, jintArray numCharsRtrn)
{
	char *ptrStrBuf = (char*)env->GetPrimitiveArrayCritical(strBuf, JNI_FALSE);
	uint32 *ptrNumCharsRtrn = (uint32*)env->GetPrimitiveArrayCritical(numCharsRtrn, JNI_FALSE);
	jint errCode = (jint)Native_Device_GetVersion(ptrStrBuf, (uint32)env->GetArrayLength(strBuf), ptrNumCharsRtrn);
	env->ReleasePrimitiveArrayCritical(strBuf, ptrStrBuf, JNI_ABORT);
	env->ReleasePrimitiveArrayCritical(numCharsRtrn, ptrNumCharsRtrn, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Dev_GetName
 * Signature: ([B[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Dev_1GetName
  (JNIEnv *env, jclass, jbyteArray strBuf, jintArray numCharsRtrn)
{
	char *ptrStrBuf = (char*)env->GetPrimitiveArrayCritical(strBuf, JNI_FALSE);
	uint32 *ptrNumCharsRtrn = (uint32*)env->GetPrimitiveArrayCritical(numCharsRtrn, JNI_FALSE);
	jint errCode = (jint)Native_Device_GetName(ptrStrBuf, (uint32)env->GetArrayLength(strBuf), ptrNumCharsRtrn);
	env->ReleasePrimitiveArrayCritical(strBuf, ptrStrBuf, JNI_ABORT);
	env->ReleasePrimitiveArrayCritical(numCharsRtrn, ptrNumCharsRtrn, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetName
 * Signature: (I[B[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetName
  (JNIEnv *env, jclass, jint lineID, jbyteArray strBuf, jintArray numCharsRtrn)
{
	char *ptrStrBuf = (char*)env->GetPrimitiveArrayCritical(strBuf, JNI_FALSE);
	uint32 *ptrNumCharsRtrn = (uint32*)env->GetPrimitiveArrayCritical(numCharsRtrn, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetName(lineID, ptrStrBuf, (uint32)env->GetArrayLength(strBuf), ptrNumCharsRtrn);
	env->ReleasePrimitiveArrayCritical(strBuf, ptrStrBuf, JNI_ABORT);
	env->ReleasePrimitiveArrayCritical(numCharsRtrn, ptrNumCharsRtrn, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Dev_GetLineUIDList
 * Signature: ([I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Dev_1GetLineUIDList
  (JNIEnv *env, jclass, jintArray uidList)
{
	uint32 *ptrUIDList = (uint32*)env->GetPrimitiveArrayCritical(uidList, JNI_FALSE);
	jint errCode = (jint)Native_Device_GetLineUIDs(ptrUIDList, (uint32)env->GetArrayLength(uidList));
	env->ReleasePrimitiveArrayCritical(uidList, ptrUIDList, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Dev_GetNumLines
 * Signature: ([I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Dev_1GetNumLines
  (JNIEnv *env, jclass, jintArray numLinesRtrn)
{
	uint32 *ptrnumLinesRtrn = (uint32*)env->GetPrimitiveArrayCritical(numLinesRtrn, JNI_FALSE);
	jint errCode = (jint)Native_Device_GetNumLines(ptrnumLinesRtrn);
	env->ReleasePrimitiveArrayCritical(numLinesRtrn, ptrnumLinesRtrn, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetSamplerateHz
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetSamplerateHz
  (JNIEnv *env, jclass, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetSampleRateHz(lineID, ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetNumBytesPerSample
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetNumBytesPerSample
  (JNIEnv *env, jclass, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetNumBytesPerSample(lineID, ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_Line_GetNumChannels
 * Signature: (I[I)I
 */
JNIEXPORT jint JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1Line_1GetNumChannels
  (JNIEnv *env, jclass, jint lineID, jintArray value)
{
	uint32 *ptrValue = (uint32*)env->GetPrimitiveArrayCritical(value, JNI_FALSE);
	jint errCode = (jint)Native_Line_GetNumChannels(lineID, ptrValue);
	env->ReleasePrimitiveArrayCritical(value, ptrValue, JNI_ABORT);
	return errCode;
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_GetErrorMsg
 * Signature: (I[B[I)V
 */
JNIEXPORT void JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1GetErrorMsg
  (JNIEnv *env, jclass, jint errCode, jbyteArray strBuf, jintArray numCharsRtrn)
{
	char *ptrStrBuf = (char*)env->GetPrimitiveArrayCritical(strBuf, JNI_FALSE);
	uint32 *ptrNumCharsRtrn = (uint32*)env->GetPrimitiveArrayCritical(numCharsRtrn, JNI_FALSE);
	Native_GetErrorMsg(errCode, ptrStrBuf, (uint32)env->GetArrayLength(strBuf), ptrNumCharsRtrn);
	env->ReleasePrimitiveArrayCritical(strBuf, ptrStrBuf, JNI_ABORT);
	env->ReleasePrimitiveArrayCritical(numCharsRtrn, ptrNumCharsRtrn, JNI_ABORT);
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_IsError
 * Signature: (I)Z
 */
JNIEXPORT jboolean JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1IsError
  (JNIEnv *, jclass, jint errCode)
{
	return (jboolean)Native_IsError(errCode);
}

/*
 * Class:     de_ses_common_nativelibs_NativePCMDevice
 * Method:    JNIDev_IsWarning
 * Signature: (I)Z
 */
JNIEXPORT jboolean JNICALL Java_de_ses_common_nativelibs_NativePCMDevice_JNIDev_1IsWarning
  (JNIEnv *, jclass, jint errCode)
{
	return (jboolean)Native_IsWarning(errCode);
}
